This data set contains the geometry for each US State Plane Zone along with the EPSG code for its projected coordinate system. The geometry was gathered from an arcgis hub data set, and the epsg codes were gathered from epsg.io
This data set contains the geometry for each US State Plane Zone along with the EPSG code for its projected coordinate system. The geometry was gathered from an arcgis hub data set, and the epsg codes were gathered from epsg.io